@@ -1,6 +1,7 @@
 import hildon
+import ui
 
-class Decken800GUI(DeckenGUI):
+class Decken800GUI(ui.DeckenGUI):
 	
 	def __init__(self):
 		
